
%define oname Ardour
%define maj 4

# gcc 4.8 doesn't seem to like bluetooth headers with strict
%bcond_with strict

# the test scripts seem to be broken
%bcond_with tests

# whether to do a verbose build
%bcond_without verbose_build
%if %{with verbose_build}
%global _verbose -v
%else
%global _verbose %{nil}
%endif

%global backends jack,alsa,dummy

%global man_langs_encodings :UTF-8 es:UTF-8 fr:ISO-8859-1 ru:KOI8-R

# Don't generate provides for internal shared objects and plugins
%global internal_libs_re (ardour.*|audiographer|canvas|evoral|gtkmm2ext|jack_audiobackend|midipp|pan[12]in2out|panbalance|panvbap|pbd|qmdsp|timecode)
%global __provides_exclude_from ^%{_libdir}/(%{name}|lv2)/.*$
%global __requires_exclude ^lib%{internal_libs_re}\.so.*$

# This package is named ardour4 to allow parallel installation with older versions of Ardour (2 and 3).
Name:       ardour4
Version:    4.7.0
Release:    %mkrel 1
Summary:    Digital Audio Workstation
Group:      Sound
License:    GPLv2+
URL:        http://ardour.org
Source0:    Ardour-%{version}.tar.xz
Source1:    LICENSING
#---------------------------------------------
BuildRequires: desktop-file-utils
BuildRequires:  doxygen
BuildRequires:  gettext
BuildRequires:  graphviz
BuildRequires: %{_lib}alsa2-devel 
BuildRequires: %{_lib}atk1.0-devel 
BuildRequires: %{_lib}atkmm1.6-devel 
BuildRequires: %{_lib}aubio-devel
BuildRequires: %{_lib}boost-devel
BuildRequires: %{_lib}cairo-devel
BuildRequires: %{_lib}cairomm1.0-devel
BuildRequires: %{_lib}cppunit-devel
BuildRequires: %{_lib}curl-devel 
BuildRequires: %{_lib}dbus-1-devel
BuildRequires: %{_lib}fftw-devel 
BuildRequires: %{_lib}fontconfig-devel 
BuildRequires: %{_lib}fontconfig1
BuildRequires: %{_lib}freetype6-devel 
BuildRequires: %{_lib}gdk_pixbuf2.0_0-devel 
BuildRequires: %{_lib}glib2.0-devel 
BuildRequires: %{_lib}glibmm2.4-devel 
BuildRequires: %{_lib}gtk+2.0_0-devel
BuildRequires: %{_lib}gtkmm2.4-devel 
BuildRequires: %{_lib}jack-devel 
BuildRequires: %{_lib}lilv-devel 
BuildRequires: %{_lib}lo-devel 
BuildRequires: %{_lib}lrdf2-devel 
BuildRequires: %{_lib}ltc-devel 
BuildRequires: %{_lib}pango1.0-devel
BuildRequires: %{_lib}pangomm2.4-devel 
BuildRequires: %{_lib}raptor2-devel 
BuildRequires: %{_lib}rubberband-devel 
BuildRequires: %{_lib}samplerate-devel 
BuildRequires: %{_lib}sndfile-devel 
BuildRequires: %{_lib}suil-devel
BuildRequires: %{_lib}taglib-devel 
BuildRequires: %{_lib}vamp-plugin-sdk-devel 
BuildRequires: %{_lib}x11-devel 
BuildRequires: %{_lib}xml2-devel 
BuildRequires: lv2-devel 
BuildRequires: x11-proto-devel 
#--------------------------------------------
BuildConflicts: %{_lib}cwiid-devel
#--------------------------------------------
Requires:	jackit
Requires:	gtk-engines2
Requires:       fonts-ttf-droid


%description
Ardour is a multi-channel digital audio workstation, allowing users to record,
edit, mix and master audio and MIDI projects. It is targeted at audio
engineers, musicians, soundtrack editors and composers.

%prep
%setup -q -n Ardour-%{version}

# use versionized name for all and reencode some man pages
for lang_enc in %{man_langs_encodings}; do
    lang="${lang_enc%%:*}"
    enc="${lang_enc#*:}"
    if [ -n "$lang" ]; then
        lang=".${lang}"
    fi
    fromfile="ardour.1${lang}"
    tofile="%{name}.1${lang}"
    iconv -f "$enc" -t UTF-8 "$fromfile" > "$tofile"
    touch -r "$fromfile" "$tofile"
done

cp %{SOURCE1} .

%build
export LC_ALL=en_US.UTF-8
./waf configure \
%if %{with strict}
    --strict \
%endif
%if %{with tests}
    --test \
%endif
    --prefix="%_prefix" \
    --bindir="%_bindir" \
    --configdir="%_sysconfdir" \
    --datadir="%_datadir" \
    --includedir="%_includedir" \
    --libdir="%_libdir" \
    --mandir="%_mandir" \
    --docdir="%_docdir" \
    --docs \
    --freedesktop \
    --lv2 \
    --lxvst \
    --nls \
    --noconfirm \
    --no-phone-home \
    --optimize \
    --cxx11 \
%ifarch %ix86 x86_64
    --arch="%optflags -msse -mfpmath=sse -DUSE_XMMINTRIN" \
%else
    --arch="%optflags" \
%endif
    --use-external-libs \
    --with-backends=%{backends}

./waf build %{_verbose} %{?_smp_mflags}
./waf i18n %{_verbose} %{?_smp_mflags}




%install
rm -rf %buildroot
./waf --destdir=%{buildroot} install %{_verbose}

# ArdourMono.ttf is really Droid Sans Mono
ln -snf ../fonts/TTF/droid/DroidSansMono.ttf %{buildroot}%{_datadir}/%{name}/ArdourMono.ttf

# install man pages
install -d -m755 %{buildroot}%{_mandir}/man1
for lang_enc in %man_langs_encodings; do
    lang="${lang_enc%%:*}"
    if [ -n "$lang" ]; then
        _lang=".${lang}"
    else
        _lang=""
    fi
    fromfile="%{name}.1${_lang}"
    todir="%{buildroot}%{_mandir}/${lang}/man1"
    tofile="${todir}/%{name}.1"
    install -d -m755 "$todir"
    install -p -m644 "$fromfile" "$tofile"
done

# install icons to freedesktop locations
for s in 16 22 32 48 256 512; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps
    ln -s ../../../../%{name}/icons/ardour_icon_${s}px.png \
       %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/%{name}.png
done

cat>%{name}.desktop<<EOF
[Desktop Entry]
Comment=Digital Audio Workstation
Comment[en_GB]=Digital Audio Workstation
Exec=ardour%{maj}
GenericName=%{oname}
GenericName[en_GB]=%{oname}
Icon=%{name}%{maj}
MimeType=application/x-%{name};
Name=%{oname}
Name[en_GB]=%{oname}
StartupNotify=true
Terminal=false
Type=Application
Categories=AudioVideo;Audio;X-MandrivaLinux-Multimedia-Sound;
EOF

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}.desktop


%find_lang %{name}
%find_lang gtk2_%{name}
%find_lang gtkmm2ext3

# Collect non-locale data files and (all) directories
find %{buildroot}%{_datadir}/%{name} | \
    sed 's|^%{buildroot}||g' | \
    while read f; do
        # *sigh*
        if [ "$f" = "${f/ /}" ]; then
            _f="$f"
        else
            _f="\"${f}\""
        fi

        if [ -d "%{buildroot}${f}" ]; then
            echo "%%dir ${_f}"
        else
            if [ "${f}" = "${f#%{_datadir}/%{name}/locale}" ]; then
                echo "${_f}"
            fi
        fi
    done > %{name}-datafiles.list

%if %{with tests}
%check
WAFTPATH="$PWD/doc/waft"
pushd libs/ardour
sh "$WAFTPATH" --targets=libardour-tests && ./run-tests.sh
popd
%endif

rm -f %{buildroot}%{_bindir}/run-tests

%post
/bin/touch --no-create %{_datadir}/icons/hicolor &> /dev/null || :
/bin/touch --no-create %{_datadir}/mime/packages &> /dev/null || :
/usr/bin/update-desktop-database &> /dev/null || :

%postun
/usr/bin/update-desktop-database &> /dev/null || :
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /bin/touch --no-create %{_datadir}/mime/packages &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
    /usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
/usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :

%files -f %{name}.lang -f gtk2_%{name}.lang -f gtkmm2ext3.lang -f %{name}-datafiles.list
%doc COPYING LICENSING
%{_bindir}/%{name}
%{_bindir}/%{name}-export
%config(noreplace) %{_sysconfdir}/%{name}
%{_libdir}/%{name}
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/%{name}.1*
%{_mandir}/*/man1/%{name}.1*
%{_datadir}/%{name}/locale/*/LC_MESSAGES/*.mo

%changelog
* Thu Sep 15 2016 adrianomorselli <adrianomorselli> 4.7.0-1uplos2016
- rebuild

* Tue May 31 2016 bb <bb> 4.7.0-1pclos2016
- update

* Tue Jan 19 2016 bb <bb> 4.6.0-1pclos2016
- update

* Sun Dec 20 2015 bb <bb> 4.4.0-1pclos2015
- update

* Fri Jun 26 2015 pp <pp> 4.1.0-1pclos2015
- update

